-- by modelleicher
-- www.schwabenmodding.bplaced.net
-- date 15.07.2013 
-- set visibility of an x amount of twinwheels true/false and saves the state in the savegame, so at game restart the state is the same as at save
-- version 1  (released with Schlueter Super 1250VL LS Special)
-- version 1.1 (for MoreRealistic Use, released with Schlueter Super 1250VL LS Special MR) date 20.02.2014 
-- version 1.2 (for MoreRealistic Use) als Reifendruckanlagen script date 10.03.2014 

RDA = {};

function RDA.prerequisitesPresent(specializations)
    return true;
end;

function RDA:load(xmlFile)
	self.changeRDAState = RDA.changeRDAState;
	self.tyreGripFXTW = Utils.getNoNil(getXMLFloat(xmlFile, "vehicle.RDA#tyreGripFXwithRDAOn"), 1.2);	-- MR Version 
	self.tyreGripFXTWBackup = self.realTyreGripFx; -- backup normal tyre grip fx
	self.RDA = {};
	self.RDACnt = getXMLInt(xmlFile, "vehicle.RDA#count");
	if self.RDACnt ~= nil and self.RDACnt > 0 then
		for i=1, self.RDACnt do
			local index = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.RDA.RDA"..i.."#index"));
			if index ~= "" and index ~= nil then
				table.insert(self.RDA, index);
			end;
		end;
	end;
	self.RDAState = false;
	self:changeRDAState(self.RDAState);
end;
function RDA:readStream(streamId, connection)  
     self:changeRDAState(streamReadBool(streamId), true);  
end;
function RDA:writeStream(streamId, connection)  
    streamWriteBool(streamId, self.RDAState);  
end;
function RDA:delete()
end;
function RDA:mouseEvent(posX, posY, isDown, isUp, button)
end;
function RDA:keyEvent(unicode, sym, modifier, isDown)
end;
function RDA:changeRDAState(state, noEventSend)
	changeRDAStateEvent.sendEvent(self, state, noEventSend);
	self.RDAState = state;
	for i=1, self.RDACnt do
		setVisibility(self.RDA[i], state);
	end;
	if state then -- addet for MR version, more grip if RDA are on
		self.realTyreGripFx = self.tyreGripFXTW;
	else
		self.realTyreGripFx = self.tyreGripFXTWBackup;
	end;
end;

function RDA:update(dt)
	if self:getIsActiveForInput() then
		if InputBinding.hasEvent(InputBinding.ToggleRDA) then
			self:changeRDAState(not self.RDAState);
		end;
	end;
end;
function RDA:draw()
	g_currentMission:addHelpButtonText(g_i18n:getText("ToggleRDA"), InputBinding.ToggleRDA);
end;
function RDA:onEnter()
end;
function RDA:onLeave()
end;

function RDA:loadFromAttributesAndNodes(xmlFile, key, resetVehicles)
	if not resetVehicles then
		local state = Utils.getNoNil(getXMLBool(xmlFile, key.."#RDAState"));
		self:changeRDAState(state);
	end;
	return BaseMission.VEHICLE_LOAD_OK;
end;

function RDA:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'RDAState="'..tostring(self.RDAState)..'"';
	local nodes = nil;
	return attributes,nodes;
end;



changeRDAStateEvent = {};
changeRDAStateEvent_mt = Class(changeRDAStateEvent, Event);
InitEventClass(changeRDAStateEvent, "changeRDAStateEvent");

function changeRDAStateEvent:emptyNew()  
    local self = Event:new(changeRDAStateEvent_mt );
    self.className="changeRDAStateEvent";
    return self;
end;
function changeRDAStateEvent:new(vehicle, state) 
    self.vehicle = vehicle;
    self.state = state;
    return self;
end;
function changeRDAStateEvent:readStream(streamId, connection)  
    local id = streamReadInt32(streamId); 
    self.state = streamReadBool(streamId); 
    self.vehicle = networkGetObject(id); 
    self:run(connection);  
end;
function changeRDAStateEvent:writeStream(streamId, connection)   
    streamWriteInt32(streamId, networkGetObjectId(self.vehicle));	
    streamWriteBool(streamId, self.state );   
end;
function changeRDAStateEvent:run(connection) 
    self.vehicle:changeRDAState(self.state, true);
	if not connection:getIsServer() then  
		g_server:broadcastEvent(changeRDAStateEvent:new(self.vehicle, self.state), nil, connection, self.object);
	end;
end;
function changeRDAStateEvent.sendEvent(vehicle, state, noEventSend)  
	if noEventSend == nil or noEventSend == false then
		if g_server ~= nil then   
			g_server:broadcastEvent(changeRDAStateEvent:new(vehicle, state), nil, nil, vehicle);
		else 
			g_client:getServerConnection():sendEvent(changeRDAStateEvent:new(vehicle, state));
		end;
	end;
end;